==> vue-icon-3.23.0.tgz: package/lib/pushpin.js <==
import { svg } from "@opentiny/vue-common";
import { createElementBlock, openBlock, createElementVNode } from "vue";
var _hoisted_1 = {
  width: "16",
  height: "16",
  viewBox: "0 0 16 16",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
var _hoisted_2 = /* @__PURE__ */ createElementVNode(
  "defs",
  null,
  [/* @__PURE__ */ createElementVNode("clipPath", {
    id: "pushpin_svg__a"
  }, [/* @__PURE__ */ createElementVNode("path", {
    fill: "#191919",
    d: "M0 0h16v16H0z"
  })])],
  -1
  /* HOISTED */
);
var _hoisted_3 = /* @__PURE__ */ createElementVNode(
  "g",
  {
    "clip-path": "url(#pushpin_svg__a)"
  },
  [/* @__PURE__ */ createElementVNode("path", {
    d: "M10.68 1.86c.42-.35 1.04-.32 1.42.06l1.97 1.97c.38.38.41 1 .06 1.41L11.3 8.66l.38.38c.38.38.4.97.08 1.39l-.08.09-1.93 1.93c-.41.41-1.08.41-1.49 0l-2.01-2.01-3.32 3.33c-.2.2-.52.2-.71 0-.2-.19-.2-.51 0-.71l3.33-3.32-2.01-2.02c-.39-.38-.41-.99-.07-1.41l.07-.07 1.92-1.93c.41-.41 1.08-.41 1.49 0l.38.38 3.35-2.83Zm.67.76L7.27 6.05 6.24 5.02a.048.048 0 0 0-.07 0L4.24 6.95c-.02.02-.02.05 0 .07l4.73 4.73c.02.01.05.01.07 0l1.93-1.93c.02-.02.02-.05 0-.07L9.94 8.72l3.42-4.06c.02-.02.02-.05 0-.07l-2.01-1.97Z",
    fill: "#191919"
  })],
  -1
  /* HOISTED */
);
var _hoisted_4 = [_hoisted_2, _hoisted_3];
function render(_ctx, _cache) {
  return openBlock(), createElementBlock("svg", _hoisted_1, [].concat(_hoisted_4));
}
var Pushpin = {
  render
};
var index = function index2() {
  return svg({
    name: "IconPushpin",
    component: Pushpin
  })();
};
export {
  index as default
};

==> vue-icon-3.24.0.tgz: package/lib/pushpin.js <==
import { svg } from "@opentiny/vue-common";
import { createElementBlock, openBlock, createElementVNode } from "vue";
var _hoisted_1 = {
  width: "16",
  height: "16",
  viewBox: "0 0 16 16",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
var _hoisted_2 = /* @__PURE__ */ createElementVNode(
  "defs",
  null,
  [/* @__PURE__ */ createElementVNode("clipPath", {
    id: "pushpin_svg__a"
  }, [/* @__PURE__ */ createElementVNode("path", {
    d: "M0 0h16v16H0z"
  })])],
  -1
  /* HOISTED */
);
var _hoisted_3 = /* @__PURE__ */ createElementVNode(
  "g",
  {
    "clip-path": "url(#pushpin_svg__a)"
  },
  [/* @__PURE__ */ createElementVNode("path", {
    d: "M10.68 1.86c.42-.35 1.04-.32 1.42.06l1.97 1.97c.38.38.41 1 .06 1.41L11.3 8.66l.38.38c.38.38.4.97.08 1.39l-.08.09-1.93 1.93c-.41.41-1.08.41-1.49 0l-2.01-2.01-3.32 3.33c-.2.2-.52.2-.71 0-.2-.19-.2-.51 0-.71l3.33-3.32-2.01-2.02c-.39-.38-.41-.99-.07-1.41l.07-.07 1.92-1.93c.41-.41 1.08-.41 1.49 0l.38.38 3.35-2.83Zm.67.76L7.27 6.05 6.24 5.02a.048.048 0 0 0-.07 0L4.24 6.95c-.02.02-.02.05 0 .07l4.73 4.73c.02.01.05.01.07 0l1.93-1.93c.02-.02.02-.05 0-.07L9.94 8.72l3.42-4.06c.02-.02.02-.05 0-.07l-2.01-1.97Z"
  })],
  -1
  /* HOISTED */
);
var _hoisted_4 = [_hoisted_2, _hoisted_3];
function render(_ctx, _cache) {
  return openBlock(), createElementBlock("svg", _hoisted_1, [].concat(_hoisted_4));
}
var Pushpin = {
  render
};
var index = function index2() {
  return svg({
    name: "IconPushpin",
    component: Pushpin
  })();
};
export {
  index as default
};
